@@ -1,7 +1,7 @@
 library(nanotime)
 suppressMessages(library(bit64))
 
-isSolaris <- Sys.info()[["sysname"]] == "SunOS"
+extended_tests <- Sys.getenv("CI", "") != ""
 
 savedFormat <- NULL
 one_second  <- 1e9
@@ -36,27 +36,25 @@ expect_identical(nanoival.start(ni),  c(a=nanotime("2013-01-01 00:00:00"),
     expect_identical(nanoival.sopen(ni), c(a=FALSE, b=FALSE, c=TRUE, d=TRUE)) &
     expect_identical(nanoival.eopen(ni), c(a=TRUE, b=FALSE, c=TRUE, d=FALSE))
 
-if (!isSolaris) {
-    expect_identical(length(as.nanoival(vector("character", 0))), 0L)
-    expect_identical(as.nanoival("-2013-01-01 00:00:00 America/New_York -> 2014-01-01 00:00:00 America/New_York+"),
-                     nanoival(nanotime("2013-01-01 00:00:00 America/New_York"),
-                              nanotime("2014-01-01 00:00:00 America/New_York"), TRUE, FALSE))
+expect_identical(length(as.nanoival(vector("character", 0))), 0L)
+expect_identical(as.nanoival("-2013-01-01 00:00:00 America/New_York -> 2014-01-01 00:00:00 America/New_York+"),
+                 nanoival(nanotime("2013-01-01 00:00:00 America/New_York"),
+                          nanotime("2014-01-01 00:00:00 America/New_York"), TRUE, FALSE))
 
-    ## test warning when we double specify the timezone:
-    expect_error(as.nanoival("-2013-01-01 00:00:00 America/New_York -> 2014-01-01 00:00:00+00:00+", tz="Europe/London"),
-                 "timezone is specified twice: in the string and as an argument")
+## test warning when we double specify the timezone:
+expect_error(as.nanoival("-2013-01-01 00:00:00 America/New_York -> 2014-01-01 00:00:00+00:00+", tz="Europe/London"),
+             "timezone is specified twice: in the string and as an argument")
 
-    ##test_as.nanoival_vector_fail <- function() {
-    expect_error(as.nanoival("-2013-01-01 00:00:00 -> 2014-01-01 00:00:00"), "`nanoival` must end with '\\+' or '-'")
-    expect_error(as.nanoival("2013-01-01 00:00:00 -> 2014-01-01 00:00:00-"), "`nanoival` must start with '\\+' or '-'") 
-    expect_error(as.nanoival("+2013-01-01 00:00:00 $$ 2014-01-01 00:00:00-"), "Parse error on 2013-01-01 00:00:00 \\$\\$ 2014-01-01 00:00:00")
-    expect_error(as.nanoival("+2013-01-01 00:00:00 -> 2014-01-01 00:00:00- "), "`nanoival` must end with '\\+' or '-'")
-    expect_error(as.nanoival("+2013-01-01 00:00:00 -> 2014-01-01 00:00:00a"), "`nanoival` must end with '\\+' or '-'")
-    expect_error(as.nanoival("+2013-01-01 00:00:00 America/New_York -> 2014-01-01 00:00:00 America/New_York %%"), "`nanoival` must end with '\\+' or '-'")
-    expect_error(as.nanoival("+2013-01-01 00:00:00 America/New_York -> 2014-01-01 00:00:00 America/New_York + "), "`nanoival` must end with '\\+' or '-'")
-    expect_error(as.nanoival("-2013-01-01 00:00:00 America/New_York -> 2014-01-01 00:00:00 America/New_YYork+"),
-                 "Cannot retrieve timezone")
-}
+##test_as.nanoival_vector_fail <- function() {
+expect_error(as.nanoival("-2013-01-01 00:00:00 -> 2014-01-01 00:00:00"), "`nanoival` must end with '\\+' or '-'")
+expect_error(as.nanoival("2013-01-01 00:00:00 -> 2014-01-01 00:00:00-"), "`nanoival` must start with '\\+' or '-'")
+expect_error(as.nanoival("+2013-01-01 00:00:00 $$ 2014-01-01 00:00:00-"), "Parse error on 2013-01-01 00:00:00 \\$\\$ 2014-01-01 00:00:00")
+expect_error(as.nanoival("+2013-01-01 00:00:00 -> 2014-01-01 00:00:00- "), "`nanoival` must end with '\\+' or '-'")
+expect_error(as.nanoival("+2013-01-01 00:00:00 -> 2014-01-01 00:00:00a"), "`nanoival` must end with '\\+' or '-'")
+expect_error(as.nanoival("+2013-01-01 00:00:00 America/New_York -> 2014-01-01 00:00:00 America/New_York %%"), "`nanoival` must end with '\\+' or '-'")
+expect_error(as.nanoival("+2013-01-01 00:00:00 America/New_York -> 2014-01-01 00:00:00 America/New_York + "), "`nanoival` must end with '\\+' or '-'")
+expect_error(as.nanoival("-2013-01-01 00:00:00 America/New_York -> 2014-01-01 00:00:00 America/New_YYork+"),
+             "Cannot retrieve timezone")
 
 expect_error(as.nanoival(aa, tz=list(1)), "argument 'tz' must be of type 'character'")
               
@@ -555,12 +553,15 @@ expect_true(is.null(names(c_xy)))
 ## --------------------------------------------------------------------------
 
 ## time - interval
+## N=143
 
 ## test_intersect_time_interval_null_interval <- function() {
-i1 <- as.nanoival(NULL)
-s1 <- seq(nanotime("2015-01-01 12:00:00"), length.out=10, by=one_second)
-expect_identical(s1[i1], as.nanotime())
-expect_identical(s1 %in% i1, rep(FALSE, 10))
+if (extended_tests) {
+    i1 <- as.nanoival(NULL)
+    s1 <- seq(nanotime("2015-01-01 12:00:00"), length.out=10, by=one_second)
+    expect_identical(s1[i1], as.nanotime())
+    expect_identical(s1 %in% i1, rep(FALSE, 10))
+}
 
 ##test_intersect.idx_unsorted <- function() {
 a <- c(nanotime("2013-12-12 12:12:12"), nanotime("2012-12-12 12:12:12"))
@@ -1349,10 +1350,9 @@ n1 <- nanotime(1)
 n2 <- nanotime(2)
 ni <- nanoival(n1, n2)
 prd <- as.nanoperiod("200y")
-if (!isSolaris) {
-    expect_warning(plus (ni, prd, "America/New_York"), "NAs produced by time overflow \\(remember that interval times are coded with 63 bits\\)")
-    expect_warning(minus(ni, prd, "America/New_York"), "NAs produced by time overflow \\(remember that interval times are coded with 63 bits\\)")
-}
+expect_warning(plus (ni, prd, "America/New_York"), "NAs produced by time overflow \\(remember that interval times are coded with 63 bits\\)")
+expect_warning(minus(ni, prd, "America/New_York"), "NAs produced by time overflow \\(remember that interval times are coded with 63 bits\\)")
+
 dur <- as.nanoduration(200*365*24*3600*1e9)
 expect_warning(ni + dur, "NAs produced by time overflow \\(remember that interval times are coded with 63 bits\\)")
 expect_warning(ni + dur, "NAs produced by time overflow \\(remember that interval times are coded with 63 bits\\)")
@@ -1385,12 +1385,11 @@ expect_identical(as.nanoival(aa), as(aa, "nanoival"))
 ## test seq:
 
 x <- as.nanoival("+2013-01-01 15:00:00 -> 2013-01-01 17:00:00-")
-if (!isSolaris) {
-    expect_identical(seq(x, by=as.nanoperiod("1m"), length.out=4, tz="America/New_York"),
-                     nanoival(seq(nanoival.start(x), by=as.nanoperiod("1m"), length.out=4, tz="America/New_York"),
-                              seq(nanoival.end(x),   by=as.nanoperiod("1m"), length.out=4, tz="America/New_York"),
-                              FALSE, TRUE))
-}
+expect_identical(seq(x, by=as.nanoperiod("1m"), length.out=4, tz="America/New_York"),
+                 nanoival(seq(nanoival.start(x), by=as.nanoperiod("1m"), length.out=4, tz="America/New_York"),
+                          seq(nanoival.end(x),   by=as.nanoperiod("1m"), length.out=4, tz="America/New_York"),
+                          FALSE, TRUE))
+
 y <- as.nanoival("+2013-01-04 15:00:00 -> 2013-01-04 17:00:00-")
 expect_identical(seq(x, y, by=as.nanoduration("24:00:00")),
                  nanoival(seq(nanoival.start(x), by=as.nanoperiod("1d"), length.out=4, tz="UTC"),
@@ -1432,19 +1431,21 @@ expect_identical(nanoival.sopen(nanoival()), logical())
 expect_identical(nanoival.eopen(nanoival()), logical())
 
 ## set ops:
-expect_identical(union(nanoival(nanotime(1), nanotime(2)), nanoival()), nanoival(nanotime(1), nanotime(2)))
-expect_identical(intersect(nanoival(nanotime(1), nanotime(2)), nanoival()), nanoival())
-expect_identical(setdiff(nanoival(nanotime(1), nanotime(2)), nanoival()), nanoival(nanotime(1), nanotime(2)))
-expect_identical(setdiff.idx(nanotime(), nanoival()), numeric())
-expect_identical(setdiff.idx(nanotime(1), nanoival()), 1)
-expect_identical(setdiff.idx(nanotime(), nanoival(nanotime(1), nanotime(2))), numeric())
-expect_identical(intersect(nanotime(1), nanoival()), nanotime())
-expect_identical(intersect(nanotime(), nanoival(nanotime(1), nanotime(2))), nanotime())
-expect_identical(intersect.idx(nanotime(1), nanoival()), list(x=numeric(), y=numeric()))
-expect_identical(intersect.idx(nanotime(), nanoival(nanotime(1), nanotime(2))), list(x=numeric(), y=numeric()))
-expect_identical(nanotime() %in% nanoival(nanotime(1), nanotime(2)), logical(0))
-expect_identical(nanotime(1:10) %in% nanoival(), rep(FALSE, 10))
-expect_identical(is.na(as.nanoival()), logical())
+if (extended_tests) {
+    expect_identical(union(nanoival(nanotime(1), nanotime(2)), nanoival()), nanoival(nanotime(1), nanotime(2)))
+    expect_identical(intersect(nanoival(nanotime(1), nanotime(2)), nanoival()), nanoival())
+    expect_identical(setdiff(nanoival(nanotime(1), nanotime(2)), nanoival()), nanoival(nanotime(1), nanotime(2)))
+    expect_identical(setdiff.idx(nanotime(), nanoival()), numeric())
+    expect_identical(setdiff.idx(nanotime(1), nanoival()), 1)
+    expect_identical(setdiff.idx(nanotime(), nanoival(nanotime(1), nanotime(2))), numeric())
+    expect_identical(intersect(nanotime(1), nanoival()), nanotime())
+    expect_identical(intersect(nanotime(), nanoival(nanotime(1), nanotime(2))), nanotime())
+    expect_identical(intersect.idx(nanotime(1), nanoival()), list(x=numeric(), y=numeric()))
+    expect_identical(intersect.idx(nanotime(), nanoival(nanotime(1), nanotime(2))), list(x=numeric(), y=numeric()))
+    expect_identical(nanotime() %in% nanoival(nanotime(1), nanotime(2)), logical(0))
+    expect_identical(nanotime(1:10) %in% nanoival(), rep(FALSE, 10))
+    expect_identical(is.na(as.nanoival()), logical())
+}
 
 ## all.equal:
 expect_identical(all.equal(nanoival(nanotime(1), nanotime(2)), nanoival(nanotime(1), nanotime(2))), TRUE)
